Module admission

Module admission 

Admission policies for deciding whether cache misses should be stored.

Enums

Decision
The result of observing an absent cache key.

Traits

AdmissionPolicy
Policy invoked after storage reports that a cache key is absent.