pub struct DirectiveValue(pub Vec<u8>);Expand description
Cache control directive value type
Tuple Fields
0: Vec<u8>Implementations
Sourceimpl DirectiveValue
impl DirectiveValue
Sourcepub fn parse_as_bytes(&self) -> &[u8] ⓘ
pub fn parse_as_bytes(&self) -> &[u8] ⓘ
A DirectiveValue without quotes (").
Sourcepub fn parse_as_str(&self) -> Result<&str>
pub fn parse_as_str(&self) -> Result<&str>
A DirectiveValue without quotes (") as str.
Sourcepub fn parse_as_delta_seconds(&self) -> Result<u32>
pub fn parse_as_delta_seconds(&self) -> Result<u32>
Parse the DirectiveValue as delta seconds
"s are ignored. The value is capped to DELTA_SECONDS_OVERFLOW_VALUE.
Sourcepub fn parse_as_delta_seconds_floor(&self) -> Result<u32>
pub fn parse_as_delta_seconds_floor(&self) -> Result<u32>
Parse the DirectiveValue as delta seconds, permitting a fractional component.
Values with a fractional part are rounded down (floored) to the nearest
non-negative integer: e.g. 1.9 -> 1, 0.5 -> 0. This is useful
for compatibility with upstreams that emit fractional ttls (which
RFC 9111 strict integer parsing rejects).
Integer parsing is attempted first, so strictly-numeric values (including overflow-capped values and quoted integers) behave identically to Self::parse_as_delta_seconds. Negative, non-finite, or non-numeric values still return an error.
"s are ignored. The value is capped to DELTA_SECONDS_OVERFLOW_VALUE.