CachePhase

Enum CachePhase 

pub enum CachePhase {
    Disabled(NoCacheReason),
    Uninit,
    Bypass,
    CacheKey,
    Hit,
    Miss,
    Stale,
    StaleUpdating,
    Expired,
    Revalidated,
    RevalidatedNoCache(NoCacheReason),
}
This reflects the phase of HttpCache during the lifetime of a request

Variants



Disabled(NoCacheReason)

Cache disabled, with reason (NeverEnabled if never explicitly used)



Uninit

Cache enabled but nothing is set yet



Bypass

Cache was enabled, the request decided not to use it



CacheKey

Awaiting the cache key to be generated



Hit

Cache hit



Miss

No cached asset is found



Stale

A staled (expired) asset is found



StaleUpdating

A staled (expired) asset was found, but another request is revalidating it



Expired

A staled (expired) asset was found, so a fresh one was fetched



Revalidated

A staled (expired) asset was found, and it was revalidated to be fresh



RevalidatedNoCache(NoCacheReason)

Revalidated, but deemed uncacheable, so we do not freshen it

Implementations

Source

impl CachePhase

pub fn as_str(&self) -> &'static str

Convert CachePhase as str, for logging and debugging.