Module eviction

Module eviction 

Cache eviction module

Modules

async_lru
Async LRU eviction manager.
lru
A shared LRU cache manager
simple_lru
A simple LRU cache manager built on top of the lru crate

Structs

CacheEntryId
Storage-defined identity for a cache entry.

Enums

CacheEntryKey
The identity of an entry tracked by an eviction manager.
CacheEntryKeyRef
A borrowed cache entry identity used for exact eviction-manager lookups.

Traits

EvictionManager
The trait that a cache eviction algorithm needs to implement.