pub enum PurgeTarget<'a> {
Active(&'a CompactCacheKey),
Exact(&'a CacheEntryKey),
}Expand description
The entry a Storage::purge call should remove.
Variants
Active(&'a CompactCacheKey)
Remove storage’s current entry for this logical cache key.
This targets one entry. Storage that retains multiple generations for a logical key does not need to remove inactive generations. Storage must not remove an entry with a different logical key. When storage retains multiple generations, it may select which identity to remove.
Exact(&'a CacheEntryKey)
Remove this exact cache entry.
Storage must match the complete identity, including any CacheEntryId.
Implementations
Sourceimpl<'a> PurgeTarget<'a>
impl<'a> PurgeTarget<'a>
Sourcepub fn key(self) -> &'a CompactCacheKey
pub fn key(self) -> &'a CompactCacheKey
Return the target’s logical cache key.
Sourcepub fn removed_entry(self, id: Option<CacheEntryId>) -> CacheEntryKeyRef<'a>
pub fn removed_entry(self, id: Option<CacheEntryId>) -> CacheEntryKeyRef<'a>
Return a borrowed identity for the removed entry.
id supplies identity discovered while resolving a PurgeTarget::Active target. It is
ignored for a PurgeTarget::Exact target, which already contains the complete identity;
if supplied, it must match that identity.