#[non_exhaustive]pub struct CacheOptionOverrides {
pub wait_timeout: Option<Duration>,
pub max_lock_retries: Option<usize>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.wait_timeout: Option<Duration>How long a cache lock reader should wait before giving up.
max_lock_retries: Option<usize>How many times a cache lock reader should retry lookup after waiting on a lock.