pub struct CacheKey {
pub user_tag: String,
pub extensions: Extensions,
/* private fields */
}Expand description
General purpose cache key
Fields
user_tag: StringAn extra tag for identifying users
For example, if the storage backend implements per user quota, this tag can be used.
extensions: ExtensionsGrab-bag for user-defined extensions. These will not be persisted to disk.
Implementations
Sourceimpl CacheKey
impl CacheKey
Sourcepub fn set_variance_key(&mut self, key: HashBinary)
pub fn set_variance_key(&mut self, key: HashBinary)
Set the value of the variance hash
Sourcepub fn get_variance_key(&self) -> Option<&HashBinary>
pub fn get_variance_key(&self) -> Option<&HashBinary>
Get the value of the variance hash
Sourcepub fn remove_variance_key(&mut self)
pub fn remove_variance_key(&mut self)
Removes the variance from this cache key
Sourcepub fn set_primary_bin_override(&mut self, key: HashBinary)
pub fn set_primary_bin_override(&mut self, key: HashBinary)
Override the primary key hash
Sourcepub fn primary_key_str(&self) -> Option<&str>
pub fn primary_key_str(&self) -> Option<&str>
Try to get primary key as UTF-8 str, if valid
Sourcepub fn namespace_str(&self) -> Option<&str>
pub fn namespace_str(&self) -> Option<&str>
Try to get namespace key as UTF-8 str, if valid
Sourceimpl CacheKey
impl CacheKey
Sourcepub fn new<B1, B2, S>(namespace: B1, primary: B2, user_tag: S) -> Self
pub fn new<B1, B2, S>(namespace: B1, primary: B2, user_tag: S) -> Self
Create a new CacheKey from the given namespace, primary, and user_tag input.
Both namespace and primary will be used for the primary hash
Sourcepub fn primary_key(&self) -> &[u8] ⓘ
pub fn primary_key(&self) -> &[u8] ⓘ
Return the primary key of this key
Sourcepub fn to_compact(&self) -> CompactCacheKey
pub fn to_compact(&self) -> CompactCacheKey
Convert this key to CompactCacheKey.